#
# spec file for package zbar
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Carlos Goncalves <cgoncalves@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libzbar0
Name:           zbar
Version:        0.10_2013_02_28
Release:        7.3
Summary:        Bar code reader
License:        LGPL-2.1+
Group:          Productivity/Other
Url:            http://zbar.sourceforge.net
Source:         %{name}-%{version}.tar.bz2
Source98:       baselibs.conf
# update.sh is used to create a new tarball based on the hg repository
Source99:       update.sh
Patch1:         fix_build.patch
Patch2:         fix-gcc5.patch
BuildRequires:  ImageMagick-devel
# required by mercurial archive only
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gtk2-devel
BuildRequires:  libqt4-devel
BuildRequires:  libtool
BuildRequires:  python-gtk-devel
BuildRequires:  xmlto
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ZBar is an open source software suite for reading bar codes from various
sources, such as video streams, image files and raw intensity sensors. It
supports many popular symbologies  (types of bar codes) including EAN-13/UPC-A,
UPC-E, EAN-8, Code 128, Code 39, Interleaved 2 of 5 and QR Code.

The flexible, layered implementation facilitates bar code scanning and decoding
for any application: use it stand-alone with the included GUI and command line
programs, easily integrate a bar code scanning widget into your Qt, GTK+ or
PyGTK GUI application, leverage one of the script or programming interfaces
(Python, Perl, C++) ...all the way down to a streamlined C library suitable for
embedded use.

%package -n %{libname}
Summary:        ZBar library
Group:          System/Libraries

%description -n %{libname}
This package provides the ZBar library.

%package -n lib%{name}-devel
Summary:        Development environment for the ZBar library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description -n lib%{name}-devel
This package contains all necessary include files, libraries,
configuration files and development tools needed to compile and link
applications using the zbar library.

%package -n python-zbar
Summary:        ZBar Python bindings
Group:          Productivity/Other
%py_requires

%description -n python-zbar
This package provides ZBar Python bindings.

%package -n libzbarqt0
Summary:        ZBar Qt bindings
Group:          System/Libraries

%description -n libzbarqt0
This package provides ZBar Qt bindings.

%package -n libzbarqt-devel
Summary:        Development environment for the ZBar Qt bindings library
Group:          Development/Libraries/C and C++
Requires:       libzbarqt0 = %{version}

%description -n libzbarqt-devel
This package contains all necessary include files, libraries,
configuration files and development tools needed to compile and link
applications using the zbar-qt library.

%package -n libzbargtk0
Summary:        ZBar Gtk bindings
Group:          System/Libraries

%description -n libzbargtk0
This package provides ZBar Gtk bindings.

%package -n libzbargtk-devel
Summary:        Development environment for the ZBar Gtk bindings library
Group:          Development/Libraries/C and C++
Requires:       libzbargtk0 = %{version}

%description -n libzbargtk-devel
This package contains all necessary include files, libraries,
configuration files and development tools needed to compile and link
applications using the zbar-gtk library.

%package -n python-zbar-gtk
Summary:        ZBar Python-Gtk bindings
Group:          Productivity/Other
Requires:       python-zbar = %{version}
%py_requires

%description -n python-zbar-gtk
This package provides ZBar Python-Gtk bindings.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
# for the Mercurial-based archive we need to get proper autoconf files
autoreconf -fi
# Mercurial only? - This should not be required in a final release version!
export CFLAGS="%{optflags} -Wno-error=parentheses -Wno-error=deprecated-declarations"
%configure --docdir=%{_docdir}/%{name} --disable-static
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm %{buildroot}%{_docdir}/zbar/INSTALL
find %{buildroot} -name '*.la' -delete

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%post -n libzbarqt0 -p /sbin/ldconfig
%postun -n libzbarqt0 -p /sbin/ldconfig

%post -n libzbargtk0 -p /sbin/ldconfig
%postun -n libzbargtk0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ChangeLog README COPYING LICENSE NEWS
%{_bindir}/zbar*
%{_mandir}/man1/*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libzbar.so.*

%files -n lib%{name}-devel
%defattr(-,root,root)
%dir %{_includedir}/%{name}
%{_includedir}/zbar.h
%{_includedir}/%{name}/*.h
%exclude %{_includedir}/%{name}/zbargtk.h
%exclude %{_includedir}/%{name}/QZBar*.h
%{_libdir}/libzbar.so
%{_libdir}/pkgconfig/zbar.pc

%files -n python-zbar
%defattr(-,root,root)
%{py_sitedir}/zbar.so

%files -n libzbarqt0
%defattr(-,root,root)
%{_libdir}/libzbarqt.so.*

%files -n libzbarqt-devel
%defattr(-,root,root)
%{_includedir}/%{name}/QZBar*.h
%{_libdir}/libzbarqt.so
%{_libdir}/pkgconfig/zbar-qt.pc

%files -n libzbargtk0
%defattr(-,root,root)
%{_libdir}/libzbargtk.so.*

%files -n libzbargtk-devel
%defattr(-,root,root)
%{_includedir}/%{name}/zbargtk.h
%{_libdir}/libzbargtk.so
%{_libdir}/pkgconfig/zbar-gtk.pc

%files -n python-zbar-gtk
%defattr(-,root,root)
%{py_sitedir}/zbarpygtk.so

%changelog
* Fri Jul  1 2016 dimstar@opensuse.org
- Add baselibs.conf (boo#987287).
* Tue Jun 14 2016 jengelh@inai.de
- Ensure SONAME symlinks stay with the library
* Thu Jun  9 2016 dimstar@opensuse.org
- Add update.sh to the source list.
* Wed Jun  8 2016 dimstar@opensuse.org
- Cleanup specfile for inclusion into openSUSE:
  + Use upstream provided tarball.
  + The devel packages follow the library basename, not the shared
    library packaging name (not parallel installable).
  + Groups for SLPP packages is System/Libraries.
  + The various devel-packages are auto-depending on each other
    based on the .pc files.
  + Move autoreconf call to build phase.
  + Pass --disable-static to configure instead of deleting the
    static libs in the end again.
* Thu Feb 28 2013 opensuse@dstoecker.de
- update to current mercurial code
* Mon Aug  6 2012 opensuse@dstoecker.de
- fix build, update to recent mercurial revision from 2012-08-06
* Sat Nov 19 2011 opensuse@dstoecker.de
- fix build for openSUSE 12.1 (update to Mercurial version from 2011-11-19)
* Fri Apr  2 2010 cgoncalves@opensuse.org
- initial package (version 0.10)
